@@ -1,8 +1,9 @@
 import click
-import shutil
+import numpy as np
 import sys
 
 from pathlib import Path
+from tifffile import imwrite
 
 from steinbock import io
 from steinbock._cli.utils import OrderedClickGroup
@@ -79,9 +80,20 @@ def prepare_cmd(
     mask_files = io.list_mask_files(mask_dir, base_files=img_files)
     Path(cpdata_dir).mkdir(exist_ok=True)
     for img_file, mask_file in zip(img_files, mask_files):
-        mask_name = f"{mask_file.stem}_mask{mask_file.suffix}"
-        shutil.copyfile(img_file, Path(cpdata_dir) / img_file.name)
-        shutil.copyfile(mask_file, Path(cpdata_dir) / mask_name)
+        img = io.read_image(img_file, native_dtype=True)
+        imwrite(
+            Path(cpdata_dir) / img_file.name,
+            data=io._to_dtype(img, np.uint16),
+            imagej=True,
+        )
+        del img
+        mask = io.read_mask(mask_file)
+        imwrite(
+            Path(cpdata_dir) / f"{mask_file.stem}_mask{mask_file.suffix}",
+            data=io._to_dtype(mask, np.uint16),
+            imagej=True,
+        )
+        del mask
     cellprofiler.create_and_save_measurement_pipeline(
         measurement_pipeline_file, len(panel.index)
     )
