@@ -76,7 +76,7 @@ class TestIMCPreprocessing:
         mcd_files = imc.list_mcd_files(imc_test_data_steinbock_path / "raw")
         txt_files = imc.list_txt_files(imc_test_data_steinbock_path / "raw")
         gen = imc.try_preprocess_images_from_disk(mcd_files, txt_files)
-        for mcd_txt_file, acquisition, img in gen:
+        for mcd_txt_file, acquisition, img, recovery_file, recovered in gen:
             pass  # TODO
 
     def test_create_panel_from_imc_panel(
